#!/usr/bin/env node

'use strict'

const fs = require('fs')
const path = require('path')
const { spawnSync } = require('child_process')

function getCommand() {
  const args = process.argv.slice(2)
  if (args.length) {
    const [command, ...modifiers] = args
    return [command, modifiers]
  }
  return ['npm', ['install']]
}

function listAllPackageJsonLocations(rootDirectory, locations = []) {
  const items = fs.readdirSync(rootDirectory, { withFileTypes: true })

  const hasPackageJson = items.find((dirent) => dirent.name == 'package.json')
  if (hasPackageJson) {
    locations.push(rootDirectory)
  }

  items
    .filter((dirent) => dirent.isDirectory() && dirent.name != 'node_modules')
    .forEach((childDirectory) => {
      const childPath = path.join(rootDirectory, childDirectory.name)
      listAllPackageJsonLocations(childPath, locations)
    })

  return locations
}

const [command, modifiers] = getCommand()
const directories = listAllPackageJsonLocations(__dirname)

for (const dir of directories) {
  console.log('Directory:', dir)
  spawnSync(command, modifiers, { cwd: dir, stdio: 'inherit' })
  console.log()
}
